==> keyclic_sdk_api-1.28.3.tar.gz: lib/model/operation_patch.dart <==
part of keyclic_sdk_api.api;

class OperationPatch {
  
  String description = null;
  

  int duration = null;
  

  String identificationNumber = null;
  

  String name = null;
  

  DateTime startDate = null;
  
  OperationPatch();

  @override
  String toString() {
    return 'OperationPatch[description=$description, duration=$duration, identificationNumber=$identificationNumber, name=$name, startDate=$startDate, ]';
  }

  OperationPatch.fromJson(Map<String, dynamic> json) {
    if (json == null) return;
    description =
        json['description']
    ;
    duration =
        json['duration']
    ;
    identificationNumber =
        json['identificationNumber']
    ;
    name =
        json['name']
    ;
    startDate = json['startDate'] == null ? null : DateTime.parse(json['startDate']);
  }

  Map<String, dynamic> toJson() {
    return {
      'description': description,
      'duration': duration,
      'identificationNumber': identificationNumber,
      'name': name,
      'startDate': startDate == null ? '' : startDate.toUtc().toIso8601String()
     };
  }

  static List<OperationPatch> listFromJson(List<dynamic> json) {
    return json == null ? new List<OperationPatch>() : json.map((value) => new OperationPatch.fromJson(value)).toList();
  }

  static Map<String, OperationPatch> mapFromJson(Map<String, Map<String, dynamic>> json) {
    var map = new Map<String, OperationPatch>();
    if (json != null && json.length > 0) {
      json.forEach((String key, Map<String, dynamic> value) => map[key] = new OperationPatch.fromJson(value));
    }
    return map;
  }
}

==> keyclic_sdk_api-1.28.6.tar.gz: lib/model/operation_patch.dart <==
part of keyclic_sdk_api.api;

class OperationPatch {
  String description = null;

  int duration = null;

  String identificationNumber = null;

  String name = null;

  DateTime startDate = null;

  OperationPatch();

  @override
  String toString() {
    return 'OperationPatch[description=$description, duration=$duration, identificationNumber=$identificationNumber, name=$name, startDate=$startDate, ]';
  }

  OperationPatch.fromJson(Map<String, dynamic> json) {
    if (json == null) return;
    description = json['description'];
    duration = json['duration'];
    identificationNumber = json['identificationNumber'];
    name = json['name'];
    startDate =
        json['startDate'] == null ? null : DateTime.parse(json['startDate']);
  }

  Map<String, dynamic> toJson() {
    return {
      'description': description,
      'duration': duration,
      'identificationNumber': identificationNumber,
      'name': name,
      'startDate': startDate == null ? '' : startDate.toUtc().toIso8601String()
    };
  }

  static List<OperationPatch> listFromJson(List<dynamic> json) {
    return json == null
        ? new List<OperationPatch>()
        : json.map((value) => new OperationPatch.fromJson(value)).toList();
  }

  static Map<String, OperationPatch> mapFromJson(
      Map<String, Map<String, dynamic>> json) {
    var map = new Map<String, OperationPatch>();
    if (json != null && json.length > 0) {
      json.forEach((String key, Map<String, dynamic> value) =>
          map[key] = new OperationPatch.fromJson(value));
    }
    return map;
  }
}
